# zettlekasten

Software that try to implement a simple zettlekasten coded in Python.

## Kesako?!

> The Zettelkasten principles
>
> A Zettelkasten is a phenomenal tool for storing and organizing your
> knowledge, extending your> memory, generating new connections
> between ideas, and increasing your writing output. However, to make
> the most of a Zettelkasten, you should follow some key principles.
>
> 1. The principle of atomicity: The term was coined by Christian
>    Tietze. It means that each note should contain one idea and one
>    idea only. This makes it possible to link ideas with a lase
>    focus.
>
> 2. The principle of autonomy: Each note should be autonomous,
>    meaning it should be self-contained and comprehensible on its
>    own. This allows notes to be moved, processed, separated, and
>    concatenated independently of its neighbors. It also ensures that
>    notes remain useful even if the original source of information
>    disappears.
>
> 3. Always link your notes: Whenever you add a note, make sure to
>    link it to already existing notes. Avoid notes that are
>    disconnected from other notes. As Luhmann himself put it, “each
>    note is just an element that derives its quality from the network
>    of links in the system. A note that is not connected to the
>    network will be lost, will be forgotten by the Zettelkasten”
>    (original in German).
>
> 4. Explain why you’re linking notes: Whenever you are connecting two
>    notes by a link, make sure to briefly explain why you are linking
>    them. Otherwise, years down the road when you revisit your notes,
>    you may have no idea why you connected them.
>
> 5. Use your own words: Don’t copy and paste. If you come across an
>    interesting idea and want to add it to your Zettelkasten, you
>    must express that idea with your own words, in a way that you’ll
>    be sure to understand years later. Don’t turn your Zettelkasten
>    into a dump of copy-and-pasted information.
>
> 6. Keep references: Always add references to your notes so that you
>    know where you got an idea from. This prevents plagiarism and
>    makes it easy for you to revisit the original source later on.
>
> 7. Add your own thoughts to the Zettelkasten: If you have thoughts
>    of your own, add them to the Zettelkasten as notes while keeping
>    in mind the principle of atomicity, autonomy, and the need for
>    linking.
>
> 8. Don’t worry about structure: Don’t worry about putting notes in
>    neat folders or into unique preconceived categories. As Schmidt
>    put it, in a Zettelkasten “there are no privileged positions” and
>    “there is no top and no bottom.” The organization develops
>    organically.
>
> 9. Add connection notes: As you begin to see connections among
>    seemingly random notes, create connection notes, that is,
>    specific notes whose purpose is to link together other notes and
>    explain their relationship.
>
> 10. Add outline notes: As ideas begin to coalesce into themes,
>     create outline notes. An outline note is a note that simply
>     contains a sequence of links to other notes, putting those other
>     notes into a particular order to create a story, narrative, or
>     argument.
>
> 11. Never delete: Don’t delete old notes. Instead, link to new notes
>     that explain what’s wrong with the old ones. In that way, your
>     Zettelkasten will reflect how your thinking has evolved over
>     time, which will prevent hindsight bias. Moreover, if you don’t
>     delete, you might revisit old ideas that may turn out to be
>     correct after all.
>
> 12. Add notes without fear: You can never have too much information
>     in your Zettelkasten. At worst, you’ll add notes that won’t be
>     of immediate use. But adding more notes will never break your
>     Zettelkasten or interfere with its proper operation. Remember,
>     Luhmann had 90,000 notes in his Zettelkasten!
>
> https://writingcooperative.com/zettelkasten-how-one-german-scholar-was-so-freakishly-productive-997e4e0ca125
